@@ -66,7 +66,7 @@ class VN_Player {
                   chroma_len = chromaWidth*chromaHeight,
                   total_len = luma_len + 2 * chroma_len // luma_len*1.5
             console.log(`[${objid}] create_image_buffer ${w}x${h}`)
-            
+
             this._format = YUVBuffer.format({
                 width: width,
                 height: height,
@@ -80,7 +80,7 @@ class VN_Player {
             this._buf = new ArrayBuffer(buf_num*total_len)
             for(let i=0; i<buf_num; i++) {
                 const offset = i*total_len
-                
+
                 this._frame[i] = YUVBuffer.frame(this._format)
                 this._frame[i].y.bytes = new Uint8Array(this._buf, offset, luma_len)
                 this._frame[i].u.bytes = new Uint8Array(this._buf, offset + luma_len, chroma_len)
@@ -131,12 +131,12 @@ class VN_Player {
     }
 
     pause() {
-        console.log(`[${this._objid}] teardown`)
+        console.log(`[${this._objid}] pause`)
         this._native_vn_player.pause()
     }
 
     resume(direction) {
-        console.log(`[${this._objid}] resume, drection: ${direction}`)
+        console.log(`[${this._objid}] resume, direction: ${direction}`)
         this._native_vn_player.resume(direction)
     }
 
@@ -144,9 +144,9 @@ class VN_Player {
         console.log(`[${this._objid}] teardown`)
         this._native_vn_player.teardown()
         this._native_vn_player = null
-		if(this._yuvCanvas !== undefined)
-			this._yuvCanvas.clear()
-        forceGC();//after forceGC ,the c++ destructor function will call
+        if(this._yuvCanvas !== undefined)
+            this._yuvCanvas.clear()
+        forceGC(); //after forceGC, the C++ destructor function will call
     }
 };
 
