@@ -11,19 +11,17 @@ const test = async () => {
         type: "text",
         name: 'server',
         message: 'server url (ex: dev1.videonext.net)',
-        initial: 'test1.vsaas.videonext.net'
-        //initial: 'dev1.videonext.net'
+        initial: 'dev1.videonext.net'
     },{
         type: "text",
         name: 'username',
         message: 'username',
-        initial: 'realm_a9'
-        //initial: 'realm_test'
+        initial: 'user'
     },{
         type: "text",
         name: 'password',
         message: 'password',
-        initial: 'q1w2e3r4t5'
+        initial: 'topse'
     }]);
 
     try {
@@ -37,7 +35,7 @@ const test = async () => {
         });
 
         const {list} = await api.getObjectList({type: "camera", withAttributes: true});
-		const workList = list.filter((camera) => camera.attributes.STATUS === "ON")
+        const workList = list.filter((camera) => camera.attributes.STATUS === "ON")
         if (workList.length === 0) {
             throw "Camera list is empty";
         }
@@ -46,14 +44,13 @@ const test = async () => {
         const camera = workList[0];
         //const obj = 'a716b3e4-7fd9-11ea-aa14-00155dd9270b';
         const obj = camera.obj;
-        //console.log("CAMERA: ", camera, obj);
 
         const {url} = await api.getMobileMediaURL({cameraid: obj});
 
         /*const new_frame = (...args) => {
             console.log(args);
         };*/
-	let vn_player = this._native_vn_player = new VN_Player({objid: obj, vsync: false})
+        let vn_player = this._native_vn_player = new VN_Player({objid: obj, vsync: false})
         vn_player.play(url);
 
         /**
@@ -65,7 +62,7 @@ const test = async () => {
             return new Promise((resolve) => setTimeout(resolve, time));
         }
 
-        sleep(5000).then(() => {
+        sleep(10000).then(() => {
             // stop
             vn_player.teardown();
             vn_player = undefined
